pub enum NanHandling {
Propagate,
Ignore,
}Expand description
Specifies how missing values should be handled in mean and variance computations.
Variants
Propagate
NaNs are passed as-is to arithmetic operators.
Ignore
NaNs are skipped, and they’re not included in the total count of entries.