pub fn col_mean<T: ComplexField>(
out: ColMut<'_, T>,
mat: MatRef<'_, T>,
nan: NanHandling,
)Expand description
computes the mean of the columns of mat and stores the result in out
pub fn col_mean<T: ComplexField>(
out: ColMut<'_, T>,
mat: MatRef<'_, T>,
nan: NanHandling,
)computes the mean of the columns of mat and stores the result in out