pub fn col_varm<T: ComplexField>(
out: ColMut<'_, T::Real>,
mat: MatRef<'_, T>,
col_mean: ColRef<'_, T>,
nan: NanHandling,
)Expand description
computes the variance of the columns of mat and stores the result in out
pub fn col_varm<T: ComplexField>(
out: ColMut<'_, T::Real>,
mat: MatRef<'_, T>,
col_mean: ColRef<'_, T>,
nan: NanHandling,
)computes the variance of the columns of mat and stores the result in out