pub fn row_mean<T: ComplexField>(
out: RowMut<'_, T>,
mat: MatRef<'_, T>,
nan: NanHandling,
)Expand description
computes the mean of the rows of mat and stores the result in out
pub fn row_mean<T: ComplexField>(
out: RowMut<'_, T>,
mat: MatRef<'_, T>,
nan: NanHandling,
)computes the mean of the rows of mat and stores the result in out