pub fn row_varm<T: ComplexField>(
out: RowMut<'_, T::Real>,
mat: MatRef<'_, T>,
row_mean: RowRef<'_, T>,
nan: NanHandling,
)Expand description
computes the variance of the rows of mat and stores the result in out
pub fn row_varm<T: ComplexField>(
out: RowMut<'_, T::Real>,
mat: MatRef<'_, T>,
row_mean: RowRef<'_, T>,
nan: NanHandling,
)computes the variance of the rows of mat and stores the result in out